@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-#	TCDR install script - kobold2@yahoo.com (Szilard Torok)
+#	TCDR install script - Szilard Torok <kobold2@yahoo.com>
 #	version: 0.3
 #	Wed Oct 16 17:04:05 CEST 2002
 
@@ -10,7 +10,7 @@
 		exit 1
 	fi
 
-	VER="1.4"
+	VER="1.6"
 
 	echo "This will install TCDR v$VER.  Ctrl-C to exit." ;read
 
@@ -28,9 +28,8 @@
 	echo "#!/bin/bash" >/usr/local/share/doc/tcdr_$VER/uninstall.sh
 	echo "echo \"This will uninstall tcdr version $VER.  Hit any key to continue.\";read">>/usr/local/share/doc/tcdr_$VER/uninstall.sh
 	echo "rm -rvf /etc/tcdrrc /usr/local/bin/tcdr /usr/local/share/doc/tcdr_$VER /usr/local/man/man1/tcdr.1.gz" >>/usr/local/share/doc/tcdr_$VER/uninstall.sh
-	chmod +x /usr/local/share/doc/tcdr_$VER/uninstall.sh && echo "Uninstall script: /usr/local/share/doc/tcdr_$VER/uninstall.sh"
+	chmod 744 /usr/local/share/doc/tcdr_$VER/uninstall.sh && echo "Uninstall script: /usr/local/share/doc/tcdr_$VER/uninstall.sh"
 #
 #####
 
 	exit 0
-
